==> aliyun-python-sdk-rds-2.1.8.tar.gz: aliyun-python-sdk-rds-2.1.8/aliyunsdkrds/request/v20140815/ModifyDBInstanceNetworkTypeRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ModifyDBInstanceNetworkTypeRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBInstanceNetworkType','rds')

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_VSwitchId(self):
		return self.get_query_params().get('VSwitchId')

	def set_VSwitchId(self,VSwitchId):
		self.add_query_param('VSwitchId',VSwitchId)

	def get_PrivateIpAddress(self):
		return self.get_query_params().get('PrivateIpAddress')

	def set_PrivateIpAddress(self,PrivateIpAddress):
		self.add_query_param('PrivateIpAddress',PrivateIpAddress)

	def get_RetainClassic(self):
		return self.get_query_params().get('RetainClassic')

	def set_RetainClassic(self,RetainClassic):
		self.add_query_param('RetainClassic',RetainClassic)

	def get_ClassicExpiredDays(self):
		return self.get_query_params().get('ClassicExpiredDays')

	def set_ClassicExpiredDays(self,ClassicExpiredDays):
		self.add_query_param('ClassicExpiredDays',ClassicExpiredDays)

	def get_VPCId(self):
		return self.get_query_params().get('VPCId')

	def set_VPCId(self,VPCId):
		self.add_query_param('VPCId',VPCId)

	def get_DBInstanceId(self):
		return self.get_query_params().get('DBInstanceId')

	def set_DBInstanceId(self,DBInstanceId):
		self.add_query_param('DBInstanceId',DBInstanceId)

	def get_ReadWriteSplittingPrivateIpAddress(self):
		return self.get_query_params().get('ReadWriteSplittingPrivateIpAddress')

	def set_ReadWriteSplittingPrivateIpAddress(self,ReadWriteSplittingPrivateIpAddress):
		self.add_query_param('ReadWriteSplittingPrivateIpAddress',ReadWriteSplittingPrivateIpAddress)

	def get_InstanceNetworkType(self):
		return self.get_query_params().get('InstanceNetworkType')

	def set_InstanceNetworkType(self,InstanceNetworkType):
		self.add_query_param('InstanceNetworkType',InstanceNetworkType)

	def get_ReadWriteSplittingClassicExpiredDays(self):
		return self.get_query_params().get('ReadWriteSplittingClassicExpiredDays')

	def set_ReadWriteSplittingClassicExpiredDays(self,ReadWriteSplittingClassicExpiredDays):
		self.add_query_param('ReadWriteSplittingClassicExpiredDays',ReadWriteSplittingClassicExpiredDays)

==> aliyun-python-sdk-rds-2.3.6.tar.gz: aliyun-python-sdk-rds-2.3.6/aliyunsdkrds/request/v20140815/ModifyDBInstanceNetworkTypeRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ModifyDBInstanceNetworkTypeRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBInstanceNetworkType','Rds')

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_VSwitchId(self):
		return self.get_query_params().get('VSwitchId')

	def set_VSwitchId(self,VSwitchId):
		self.add_query_param('VSwitchId',VSwitchId)

	def get_PrivateIpAddress(self):
		return self.get_query_params().get('PrivateIpAddress')

	def set_PrivateIpAddress(self,PrivateIpAddress):
		self.add_query_param('PrivateIpAddress',PrivateIpAddress)

	def get_RetainClassic(self):
		return self.get_query_params().get('RetainClassic')

	def set_RetainClassic(self,RetainClassic):
		self.add_query_param('RetainClassic',RetainClassic)

	def get_ClassicExpiredDays(self):
		return self.get_query_params().get('ClassicExpiredDays')

	def set_ClassicExpiredDays(self,ClassicExpiredDays):
		self.add_query_param('ClassicExpiredDays',ClassicExpiredDays)

	def get_VPCId(self):
		return self.get_query_params().get('VPCId')

	def set_VPCId(self,VPCId):
		self.add_query_param('VPCId',VPCId)

	def get_DBInstanceId(self):
		return self.get_query_params().get('DBInstanceId')

	def set_DBInstanceId(self,DBInstanceId):
		self.add_query_param('DBInstanceId',DBInstanceId)

	def get_ReadWriteSplittingPrivateIpAddress(self):
		return self.get_query_params().get('ReadWriteSplittingPrivateIpAddress')

	def set_ReadWriteSplittingPrivateIpAddress(self,ReadWriteSplittingPrivateIpAddress):
		self.add_query_param('ReadWriteSplittingPrivateIpAddress',ReadWriteSplittingPrivateIpAddress)

	def get_InstanceNetworkType(self):
		return self.get_query_params().get('InstanceNetworkType')

	def set_InstanceNetworkType(self,InstanceNetworkType):
		self.add_query_param('InstanceNetworkType',InstanceNetworkType)

	def get_ReadWriteSplittingClassicExpiredDays(self):
		return self.get_query_params().get('ReadWriteSplittingClassicExpiredDays')

	def set_ReadWriteSplittingClassicExpiredDays(self,ReadWriteSplittingClassicExpiredDays):
		self.add_query_param('ReadWriteSplittingClassicExpiredDays',ReadWriteSplittingClassicExpiredDays)
